@@ -1,6 +1,6 @@
 use std::{array, f32::consts::TAU};
 
-use glam::Vec2;
+use glam::{Mat3, Vec2};
 
 use crate::TOLERANCE;
 
@@ -94,6 +94,12 @@ impl Face {
         self.normal
     }
 
+    /// Transforms the face
+    pub fn transform(&self, transform: Mat3) -> Self {
+        let [a, b] = self.vertices;
+        Face::new([transform.transform_point2(a), transform.transform_point2(b)])
+    }
+
     /// Returns the side self is in respect to a point and normal
     pub fn side_of(&self, p: Vec2, normal: Vec2) -> Side {
         let a = (self.vertices[0] - p).dot(normal);
